Description Usage Arguments Value Note
create a menu with cuisine and number of dishes within each cuisine
1 | create_menu_cuisine_list(cuisine, ndishes)
|
cuisine |
a character vector of cuisine letter, e.g., c("A", "B", "C") |
ndishes |
an integer vector of number of dishes within each cuisine, must have the same length with cuisine, e.g., c(5L, 3L, 4L) |
menu data.table
create_menu_cuisine_list(cuisine = c("A", "B", "C"), ndishes = c(5L, 3L, 4L))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.